---
title: <span class="badge object-type-scalar"></span> KiloOhm
---
# <span class="badge object-type-scalar"></span> KiloOhm

Energy: Kiloohm (kΩ)

## Definition

```python
# Energy: Kiloohm (kΩ)
KiloOhm: typing.Literal["kohm"] = "kohm"
```
